(* Graph, a terminal time series graphing utility
   Copyright (C) 2007 N. Owen Gunden

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at
   your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *)

open ANSITerminal

(* Termdraw is a module for drawing to the terminal in a fashion that doesn't
 * waste any time redrawing anything.  When you call set_pixel, write_string,
 * or fill, it writes to an internal buffer.  When you call redraw, it compares
 * this buffer to a buffer representing the previous screen and only redraws the
 * parts that are different. *)

type t

val create : rows:int -> cols:int -> init_styles:style list -> init_character:char -> t

(* row and col are 0-indexed in this module. *)
val set_pixel : t -> char -> style list -> row:int -> col:int -> unit

val write_string : t -> row:int -> col:int -> style list -> string -> unit

val fill : t -> char -> style list -> unit

val redraw : t -> unit
